require "fis/test/version"
require 'colorize'

module Fis
  module Test
    class SkippedError < StandardError
    end

    def test(title, &b)
      begin
        if b
          result = b.call
          puts evaluate(result, title)
        else
          puts "pending:".blue + " #{title}"
        end
      rescue => e
        puts exception_handler(e, title)
      end
    end

    def skip(message=nil)
      message ||= "skipped."
      raise SkippedError.new(message)
    end

    def assert(statement)
      !!statement
    end

    def assert_equal(actual, expected)
      if expected == actual
        true
      else
        [expected, actual]
      end
    end

    private

    def exception_handler(e, title)
      if e.class == Fis::Test::SkippedError
        "skipped:".blue + " #{e.message}"
      else
        "fail:".red + " #{title}\n#{e}\n#{e.backtrace.first}"
      end
    end

    def evaluate(result, title)
      if result.is_a?(Array)
        "fail:".red + " #{title}\n      expected #{result.first} to equal #{result.last}"
      elsif result
        "pass:".green + " #{title}"
      else
        "fail:".red + " #{title}"
      end
    end

  end
end
